==> tecfy_corev2_package-1.1.54.tar.gz: lib/tecfy_core_client_package.dart <==
library tecfy_corev2_client_package;

import 'package:firebase_messaging/firebase_messaging.dart';

// import 'dart:html' as html;
import 'package:universal_html/html.dart' as html;
import 'dart:io';
import 'package:flutter/foundation.dart';
import 'package:flutter_markdown/flutter_markdown.dart';
import 'package:markdown_editable_textinput/format_markdown.dart';
import 'package:markdown_editable_textinput/markdown_text_input.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:localstorage/localstorage.dart';
import 'package:pull_to_refresh/pull_to_refresh.dart';

// import 'package:sqflite/sqflite.dart';
// import 'package:sqflite_common_ffi/sqflite_ffi.dart';
import 'package:tecfy_basic_package/tecfy_basic_package.dart';
import 'package:flutter\_localizations/flutter\_localizations.dart';
import 'dart:math';
import 'dart:convert';
// import 'package:path_provider/path_provider.dart' as path;
import 'dart:async';
import 'package:intl/intl.dart' as intl;
import 'package:url_launcher/url_launcher_string.dart';
import 'package:uuid/uuid.dart';
import 'package:web_socket_channel/io.dart';
import 'package:date_time_picker/date_time_picker.dart';
// import 'package:web_socket_channel/status.dart' as status;
import 'package:flutter/cupertino.dart';
import 'package:path/path.dart' as path;
import 'package:flutter_slidable/flutter_slidable.dart';
import 'package:flutter/services.dart';
import 'package:math_expressions/math_expressions.dart' as math_expressions;
import 'package:expressions/expressions.dart';
// import 'package:package_info/package_info.dart';
import 'package:soundpool/soundpool.dart';
import 'package:google_maps_flutter/google_maps_flutter.dart';
import 'dart:ui' as ui;
// import 'package:flutter/services.dart' show rootBundle;
// import 'package:http/http.dart' as http;
import 'package:pdf/pdf.dart';
import 'package:pdf/widgets.dart' as pw;
import 'package:printing/printing.dart';
import 'package:permission_handler/permission_handler.dart' as perm;
import 'package:ai_barcode/ai_barcode.dart';
import 'package:file_picker/file_picker.dart';
// import 'package:cross_file/src/types/interface.dart';
// import 'dart:html' if (dart.lib);
// import 'dart:html' if (dart.library.html) 'foo_web.dart' if (dart.library.io) 'foo_io.dart';

import 'package:fl_chart/fl_chart.dart';
// import 'package:fl_chart/src/chart/bar_chart/bar_chart_painter.dart';
// import 'package:fl_chart/src/chart/base/base_chart/base_chart_painter.dart';
// import 'package:fl_chart/src/utils/utils.dart' as intl;
import 'package:flutter_staggered_animations/flutter_staggered_animations.dart';
import 'package:flutter_material_color_picker/flutter_material_color_picker.dart';
import 'package:web_socket_channel/web_socket_channel.dart';
// import 'package:url_launcher/url_launcher.dart';
import 'package:bot_toast/bot_toast.dart';
import 'package:image_picker/image_picker.dart';
import 'package:simple_file_manager/simple_file_manager.dart';

// import 'bar_chart/bar_chart_page.dart';
// import 'bar_chart/bar_chart_page2.dart';
// import 'line_chart/line_chart_page.dart';
// import 'line_chart/line_chart_page2.dart';
// import 'line_chart/line_chart_page3.dart';
// import 'line_chart/line_chart_page4.dart';
// import 'pie_chart/pie_chart_page.dart';

part 'main.dart';
part 'controllers/account/login.controller.dart';
part 'controllers/entity/entity_filter.controller.dart';
part 'controllers/entity/entity_form.controller.dart';
part 'controllers/entity/entity_list.controller.dart';
part 'controllers/home/dashboard.controller.dart';
part 'interfaces/entity_transaction.interface.dart';
part 'interfaces/report_service.interface.dart';
part 'interfaces/menu.interface.dart';
part 'interfaces/init.interface.dart';
part 'interfaces/entity_action.interface.dart';
// part 'interfaces/theme.interface.dart';
part 'models/entity/action.model.dart';
part 'models/entity/entity.model.dart';
part 'models/entity/entity_category.model.dart';
part 'models/entity/entity_filter.model.dart';
part 'models/entity/permission.model.dart';
part 'models/entity/permission_action.model.dart';
part 'models/entity/property.model.dart';
part 'models/entity/report_property.model.dart';
part 'models/entity/property_bool.model.dart';
part 'models/entity/property_date.model.dart';
part 'models/entity/property_date_time.model.dart';
part 'models/entity/property_time.model.dart';
part 'models/entity/property_dropdown.model.dart';
part 'models/entity/property_file.model.dart';
part 'models/entity/property_many_to_many.model.dart';
part 'models/entity/property_number.model.dart';
part 'models/entity/property_one_to_many.model.dart';
part 'models/entity/property_other_entity_many.model.dart';
part 'models/entity/property_text.model.dart';
part 'models/entity/property_types.enum.dart';
part 'models/entity/value_types.enum.dart';
part 'models/entity/property_color.model.dart';
part 'models/entity/property_map_area.model.dart';
part 'models/entity/property_location.model.dart';
part 'models/entity/property_mark_image.model.dart';

part 'models/entity/property_dynamic_properties.model.dart';

part 'models/entity/property_html.model.dart';

part 'models/entity/property_text_multi_lang.model.dart';

part 'models/entity/property_multi_dropdown.model.dart';

part 'models/home/dashboard_base.model.dart';
part 'models/home/dashboard.model.dart';
part 'models/home/dashboard_chart.model.dart';
part 'models/message.model.dart';
part 'models/notification.model.dart';
part 'models/notification_app.model.dart';
part 'models/package.model.dart';
part 'models/package_type.model.dart';
part 'models/project/menu.model.dart';
part 'models/user.model.dart';
part 'models/project/connection.model.dart';
part 'models/helper.model.dart';

part 'services/account.service.dart';
part 'services/platform.service.dart';
part 'services/app_localizations.dart';
part 'services/app_localizations_delegate.dart';
part 'services/config.service.dart';
part 'services/database.service.dart';
part 'services/dynamic_links.dart';
part 'services/entity.service.dart';
part 'services/init.service.dart';
part 'services/log.service.dart';
part 'services/message.service.dart';
part 'services/notification_app.service.dart';
part 'services/notifications.service.dart';
part 'services/resource.service.dart';
part 'services/user_notification.service.dart';
part 'services/values.service.dart';
part 'services/web_socket.service.dart';
part 'services/connection.service.dart';
part 'services/sound.service.dart';
part 'services/timeout_message.dart';
part 'services/sync.service.dart';

part 'services/report.service.dart';

part 'services/map_service.dart';

part 'views/account/login.page.dart';
part 'views/general/sync.page.dart';
part 'views/general/local_records.page.dart';
part 'views/base.page.dart';
part 'views/components/app_bar.dart';
part 'views/components/dots_indicator.dart';
part 'views/components/entity/date.property.dart';
part 'views/components/entity/date_time.property.dart';

part 'views/components/entity/time.property.dart';

part 'views/components/entity/dropdown.property.dart';

part 'views/components/entity/dropdown_advance.property.dart';

part 'views/components/entity/entity_list_search.component.dart';

part 'views/components/entity/entity_list_tile.components.dart';

part 'views/components/entity/in_line_form.dart';

part 'views/components/entity/list_form.property.dart';

part 'views/components/entity/many_to_many.property.dart';

part 'views/components/entity/many_to_many_with_data.dart';

part 'views/components/entity/file.property.dart';

part 'views/components/general/file_manager_page.dart';

part 'views/components/entity/popup_property.componenet.dart';

part 'views/components/entity/photo_view.property.dart';

part 'views/components/entity/property.component.dart';

part 'views/components/entity/property_base.dart';

part 'views/components/entity/string.property.dart';

part 'views/components/entity/color_property.dart';

part 'views/components/entity/map_area_property.dart';

part 'views/components/entity/mark_image_property.dart';

part 'views/components/entity/location_property.dart';

part 'views/components/entity/file_multi.property.dart';

part 'views/components/home/app_bar_profile.dart';

part 'views/components/general/icon_button.componenet.dart';

part 'views/components/general/dropdown.component.dart';

part 'views/components/general/multi_dropdown_component.dart';

part 'views/components/general/data_table.componenet.dart';

// part 'views/components/home/bottom_navigation_bar.dart';
part 'views/components/general/template_text_form.component.dart';
part 'views/components/general/scanner_camera.dialog.dart';
part 'views/components/home/notification_button.dart';
part 'views/components/home/notification_icon.dart';
part 'views/components/home/setting_icon.dart';
part 'views/components/home/notification_row.dart';
part 'views/components/home/tool_bar.componenet.dart';
part 'views/components/home/title_path.componenet.dart';
part 'views/components/dashboard/dashboard_statistics.component.dart';
part 'views/components/dashboard/dashboard_chart.component.dart';
part 'views/components/dashboard/charts/bar2_chart.componenets.dart';
// part 'views/components/dashboard/charts/bar_chart.componenets.dart';
part 'views/components/dashboard/charts/line_chart.componenets.dart';
part 'views/components/entity_filter/property_filter.componenet.dart';
part 'views/components/entity/barcode.property.dart';

part 'views/entity/entity_filter.page.dart';
part 'views/entity/entity_form.pade.dart';
part 'views/entity/entity_history.pade.dart';
part 'views/entity/entity_list.page.dart';
part 'views/entity/entity_list.base.page.dart';
part 'views/merge/entity_merge.page.dart';
part 'views/merge/entity_merge_compare.page.dart';

part 'views/home/dasboard.page.dart';
part 'views/home/drawer.dart';
part 'views/home/drawer2.dart';
part 'views/home/drawer3.dart';
part 'views/home/home.page.dart';
// part 'views/home/home_template.dart';
part 'views/home/notification_list.dart';
part 'views/home/setting.dart';
part 'views/account/account.page.dart';

part 'views/message/chat.page.dart';
part 'views/message/chat_contacts.page.dart';
part 'views/report/report_detail.page.dart';
part 'views/report/report_filter.page.dart';
part 'views/report/report_list.page.dart';
part 'views/splash.page.dart';
part 'views/general/state.dart';
part 'views/general/tecfy_poweredby.dart';
part 'views/general/upgrade.page.dart';

part 'views/components/tecfy_text.dart';

// part 'views/components/general/app_text_trans.dart';

==> tecfy_corev2_package-1.1.57.tar.gz: lib/tecfy_core_client_package.dart <==
library tecfy_corev2_client_package;

import 'package:firebase_messaging/firebase_messaging.dart';

// import 'dart:html' as html;
import 'package:universal_html/html.dart' as html;
import 'dart:io';
import 'package:flutter/foundation.dart';
import 'package:flutter_markdown/flutter_markdown.dart';
import 'package:markdown_editable_textinput/format_markdown.dart';
import 'package:markdown_editable_textinput/markdown_text_input.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:localstorage/localstorage.dart';
import 'package:pull_to_refresh/pull_to_refresh.dart';

// import 'package:sqflite/sqflite.dart';
// import 'package:sqflite_common_ffi/sqflite_ffi.dart';
import 'package:tecfy_basic_package/tecfy_basic_package.dart';
import 'package:flutter\_localizations/flutter\_localizations.dart';
import 'dart:math';
import 'dart:convert';
// import 'package:path_provider/path_provider.dart' as path;
import 'dart:async';
import 'package:intl/intl.dart' as intl;
import 'package:url_launcher/url_launcher_string.dart';
import 'package:uuid/uuid.dart';
import 'package:web_socket_channel/io.dart';
import 'package:date_time_picker/date_time_picker.dart';
// import 'package:web_socket_channel/status.dart' as status;
import 'package:flutter/cupertino.dart';
import 'package:path/path.dart' as path;
import 'package:flutter_slidable/flutter_slidable.dart';
import 'package:flutter/services.dart';
import 'package:math_expressions/math_expressions.dart' as math_expressions;
import 'package:expressions/expressions.dart';
// import 'package:package_info/package_info.dart';
import 'package:soundpool/soundpool.dart';
import 'package:google_maps_flutter/google_maps_flutter.dart';
import 'dart:ui' as ui;
// import 'package:flutter/services.dart' show rootBundle;
import 'package:http/http.dart' as http;
import 'package:pdf/pdf.dart';
import 'package:pdf/widgets.dart' as pw;
import 'package:printing/printing.dart';
import 'package:permission_handler/permission_handler.dart' as perm;
import 'package:ai_barcode/ai_barcode.dart';
import 'package:file_picker/file_picker.dart';
// import 'package:cross_file/src/types/interface.dart';
// import 'dart:html' if (dart.lib);
// import 'dart:html' if (dart.library.html) 'foo_web.dart' if (dart.library.io) 'foo_io.dart';

import 'package:fl_chart/fl_chart.dart';
// import 'package:fl_chart/src/chart/bar_chart/bar_chart_painter.dart';
// import 'package:fl_chart/src/chart/base/base_chart/base_chart_painter.dart';
// import 'package:fl_chart/src/utils/utils.dart' as intl;
import 'package:flutter_staggered_animations/flutter_staggered_animations.dart';
import 'package:flutter_material_color_picker/flutter_material_color_picker.dart';
import 'package:web_socket_channel/web_socket_channel.dart';
import 'package:url_launcher/url_launcher.dart';
import 'package:bot_toast/bot_toast.dart';
import 'package:image_picker/image_picker.dart';
import 'package:simple_file_manager/simple_file_manager.dart';

// import 'bar_chart/bar_chart_page.dart';
// import 'bar_chart/bar_chart_page2.dart';
// import 'line_chart/line_chart_page.dart';
// import 'line_chart/line_chart_page2.dart';
// import 'line_chart/line_chart_page3.dart';
// import 'line_chart/line_chart_page4.dart';
// import 'pie_chart/pie_chart_page.dart';

part 'main.dart';
part 'controllers/account/login.controller.dart';
part 'controllers/entity/entity_filter.controller.dart';
part 'controllers/entity/entity_form.controller.dart';
part 'controllers/entity/entity_list.controller.dart';
part 'controllers/home/dashboard.controller.dart';
part 'interfaces/entity_transaction.interface.dart';
part 'interfaces/report_service.interface.dart';
part 'interfaces/menu.interface.dart';
part 'interfaces/init.interface.dart';
part 'interfaces/entity_action.interface.dart';
// part 'interfaces/theme.interface.dart';
part 'models/entity/action.model.dart';
part 'models/entity/entity.model.dart';
part 'models/entity/entity_category.model.dart';
part 'models/entity/entity_filter.model.dart';
part 'models/entity/permission.model.dart';
part 'models/entity/permission_action.model.dart';
part 'models/entity/property.model.dart';
part 'models/entity/report_property.model.dart';
part 'models/entity/property_bool.model.dart';
part 'models/entity/property_date.model.dart';
part 'models/entity/property_date_time.model.dart';
part 'models/entity/property_time.model.dart';
part 'models/entity/property_dropdown.model.dart';
part 'models/entity/property_file.model.dart';
part 'models/entity/property_many_to_many.model.dart';
part 'models/entity/property_number.model.dart';
part 'models/entity/property_one_to_many.model.dart';
part 'models/entity/property_other_entity_many.model.dart';
part 'models/entity/property_text.model.dart';
part 'models/entity/property_types.enum.dart';
part 'models/entity/value_types.enum.dart';
part 'models/entity/property_color.model.dart';
part 'models/entity/property_map_area.model.dart';
part 'models/entity/property_location.model.dart';
part 'models/entity/property_mark_image.model.dart';

part 'models/entity/property_dynamic_properties.model.dart';

part 'models/entity/property_html.model.dart';

part 'models/entity/property_text_multi_lang.model.dart';

part 'models/entity/property_multi_dropdown.model.dart';

part 'models/home/dashboard_base.model.dart';
part 'models/home/dashboard.model.dart';
part 'models/home/dashboard_chart.model.dart';
part 'models/message.model.dart';
part 'models/notification.model.dart';
part 'models/notification_app.model.dart';
part 'models/package.model.dart';
part 'models/package_type.model.dart';
part 'models/project/menu.model.dart';
part 'models/user.model.dart';
part 'models/project/connection.model.dart';
part 'models/helper.model.dart';

part 'services/account.service.dart';
part 'services/platform.service.dart';
part 'services/app_localizations.dart';
part 'services/app_localizations_delegate.dart';
part 'services/config.service.dart';
part 'services/database.service.dart';
part 'services/dynamic_links.dart';
part 'services/entity.service.dart';
part 'services/init.service.dart';
part 'services/log.service.dart';
part 'services/message.service.dart';
part 'services/notification_app.service.dart';
part 'services/notifications.service.dart';
part 'services/resource.service.dart';
part 'services/user_notification.service.dart';
part 'services/values.service.dart';
part 'services/web_socket.service.dart';
part 'services/connection.service.dart';
part 'services/sound.service.dart';
part 'services/timeout_message.dart';
part 'services/sync.service.dart';

part 'services/report.service.dart';

part 'services/map_service.dart';

part 'views/account/login.page.dart';
part 'views/general/sync.page.dart';
part 'views/general/local_records.page.dart';
part 'views/base.page.dart';
part 'views/components/app_bar.dart';
part 'views/components/dots_indicator.dart';
part 'views/components/entity/date.property.dart';
part 'views/components/entity/date_time.property.dart';

part 'views/components/entity/time.property.dart';

part 'views/components/entity/dropdown.property.dart';

part 'views/components/entity/dropdown_advance.property.dart';

part 'views/components/entity/entity_list_search.component.dart';

part 'views/components/entity/entity_list_tile.components.dart';

part 'views/components/entity/in_line_form.dart';

part 'views/components/entity/list_form.property.dart';

part 'views/components/entity/many_to_many.property.dart';

part 'views/components/entity/many_to_many_with_data.dart';

part 'views/components/entity/file.property.dart';

part 'views/components/general/file_manager_page.dart';

part 'views/components/entity/popup_property.componenet.dart';

part 'views/components/entity/photo_view.property.dart';

part 'views/components/entity/property.component.dart';

part 'views/components/entity/property_base.dart';

part 'views/components/entity/string.property.dart';

part 'views/components/entity/color_property.dart';

part 'views/components/entity/map_area_property.dart';

part 'views/components/entity/mark_image_property.dart';

part 'views/components/entity/location_property.dart';

part 'views/components/entity/file_multi.property.dart';

part 'views/components/home/app_bar_profile.dart';

part 'views/components/general/icon_button.componenet.dart';

part 'views/components/general/dropdown.component.dart';

part 'views/components/general/multi_dropdown_component.dart';

part 'views/components/general/data_table.componenet.dart';

// part 'views/components/home/bottom_navigation_bar.dart';
part 'views/components/general/template_text_form.component.dart';
part 'views/components/general/scanner_camera.dialog.dart';
part 'views/components/home/notification_button.dart';
part 'views/components/home/notification_icon.dart';
part 'views/components/home/setting_icon.dart';
part 'views/components/home/notification_row.dart';
part 'views/components/home/tool_bar.componenet.dart';
part 'views/components/home/title_path.componenet.dart';
part 'views/components/dashboard/dashboard_statistics.component.dart';
part 'views/components/dashboard/dashboard_chart.component.dart';
part 'views/components/dashboard/charts/bar2_chart.componenets.dart';
// part 'views/components/dashboard/charts/bar_chart.componenets.dart';
part 'views/components/dashboard/charts/line_chart.componenets.dart';
part 'views/components/entity_filter/property_filter.componenet.dart';
part 'views/components/entity/barcode.property.dart';

part 'views/entity/entity_filter.page.dart';
part 'views/entity/entity_form.pade.dart';
part 'views/entity/entity_history.pade.dart';
part 'views/entity/entity_list.page.dart';
part 'views/entity/entity_list.base.page.dart';
part 'views/merge/entity_merge.page.dart';
part 'views/merge/entity_merge_compare.page.dart';

part 'views/home/dasboard.page.dart';
part 'views/home/drawer.dart';
part 'views/home/drawer2.dart';
part 'views/home/drawer3.dart';
part 'views/home/home.page.dart';
// part 'views/home/home_template.dart';
part 'views/home/notification_list.dart';
part 'views/home/setting.dart';
part 'views/account/account.page.dart';

part 'views/message/chat.page.dart';
part 'views/message/chat_contacts.page.dart';
part 'views/report/report_detail.page.dart';
part 'views/report/report_filter.page.dart';
part 'views/report/report_list.page.dart';
part 'views/splash.page.dart';
part 'views/general/state.dart';
part 'views/general/tecfy_poweredby.dart';
part 'views/general/upgrade.page.dart';

part 'views/components/tecfy_text.dart';

// part 'views/components/general/app_text_trans.dart';
